/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2009, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.logging.logmanager;

import org.jboss.logmanager.Logger;
import org.jboss.logmanager.Level;
import org.jboss.logmanager.ExtLogRecord;
import org.jboss.logging.AbstractLoggerPluginInstance;
import org.jboss.logging.LoggerPlugin;
import java.util.Map;
import java.util.EnumMap;

/**
 * The JBoss Common Logging plugin implementation.
 */
public final class LoggerPluginInstanceImpl extends AbstractLoggerPluginInstance {

    private final Logger logger;

    public LoggerPluginInstanceImpl(final String name, final String resourceBundleName, final Logger logger, final LoggerPlugin loggerPlugin) {
        super(name, resourceBundleName, loggerPlugin);
        this.logger = logger;
    }

    private static final Map<org.jboss.logging.Logger.Level, Level> LEVELS;

    static {
        final EnumMap<org.jboss.logging.Logger.Level, Level> map = new EnumMap<org.jboss.logging.Logger.Level, Level>(org.jboss.logging.Logger.Level.class);
        map.put(org.jboss.logging.Logger.Level.TRACE, Level.TRACE);
        map.put(org.jboss.logging.Logger.Level.DEBUG, Level.DEBUG);
        map.put(org.jboss.logging.Logger.Level.INFO, Level.INFO);
        map.put(org.jboss.logging.Logger.Level.WARN, Level.WARN);
        map.put(org.jboss.logging.Logger.Level.ERROR, Level.ERROR);
        map.put(org.jboss.logging.Logger.Level.FATAL, Level.FATAL);
        LEVELS = map;
    }

    public boolean isEnabled(final org.jboss.logging.Logger.Level level) {
        return logger.isLoggable(LEVELS.get(level));
    }

    public void log(final org.jboss.logging.Logger.Level level, final String loggerFqcn, final Object message, final Object[] params, final Throwable t) {
        if (params == null) {
            logger.log(loggerFqcn, LEVELS.get(level), String.valueOf(message), t);
        } else {
            logger.log(loggerFqcn, LEVELS.get(level), String.valueOf(message), ExtLogRecord.FormatStyle.MESSAGE_FORMAT, params, t);
        }
    }

    public void logf(final org.jboss.logging.Logger.Level level, final String loggerFqcn, final String format, final Object[] params, final Throwable t) {
        if (params == null) {
            logger.log(loggerFqcn, LEVELS.get(level), format, t);
        } else {
            logger.log(loggerFqcn, LEVELS.get(level), format, ExtLogRecord.FormatStyle.PRINTF, params, t);
        }
    }
}
